@@ -83,6 +83,10 @@ add_time_out_handler(DateTodayPlugin *desktop_plugin)
   local_time = localtime(&current_time);
   int diff = 24 - local_time->tm_hour;
   diff = diff * 60 * 60 - 60*local_time->tm_min - local_time->tm_sec;
+
+  if(desktop_plugin->time_out_handler)
+    g_source_remove(desktop_plugin->time_out_handler);
+
   desktop_plugin->time_out_handler = g_timeout_add_seconds(diff, 
 							   date_today_update_day, 
 							   (gpointer) desktop_plugin);
@@ -143,10 +147,13 @@ save_settings(DateTodayPlugin* desktop_plugin)
   gchar *filename;
 
   keyFile = g_key_file_new();
+  filename = g_strconcat (HOME_DIR, DATE_TODAY_SETTINGS_FILE, NULL);
+  g_key_file_load_from_file (keyFile, filename, G_KEY_FILE_KEEP_COMMENTS, NULL);
+
   g_key_file_set_integer(keyFile, desktop_plugin->iD, "launchView", desktop_plugin->launch_view);
   g_key_file_set_integer(keyFile, desktop_plugin->iD, "size", desktop_plugin->size);
   g_key_file_set_integer(keyFile, desktop_plugin->iD, "date_format", desktop_plugin->date_format);
-  filename = g_strconcat (HOME_DIR, DATE_TODAY_SETTINGS_FILE, NULL);
+
   fileData = g_key_file_to_data (keyFile, &size, NULL);
 
   g_file_set_contents(filename, fileData, size, NULL);
